@@ -4,7 +4,9 @@
 """
 
 from __future__ import absolute_import
-from .hello import *
+from .tagenalgo import *
+from .backtest import *
+from .utils import *
 
-__version__ = '1.0.1'
+__version__ = '1.0.2'
 __license__ = 'BSD'
\ No newline at end of file
